@@ -21,4 +21,6 @@ set -o errexit
 SCRIPT_DIR="$(dirname "$(readlink -f "$0")")"
 ROOT_DIR="$(dirname "${SCRIPT_DIR}")"
 
-${FUZZ_BIN_DIR}/afl-fuzz -i fuzz-in/wasm/ -o fuzz-out -- out/gcc-fuzz/Debug/wasm2wat @@
+ENABLE="--enable-except --enable-sat --enable-sign --enable-simd --enable-thread --enable-multi --enable-tail --enable-bulk --enable-ref"
+
+${FUZZ_BIN_DIR}/afl-fuzz -i fuzz-in/wasm/ -o fuzz-out -- out/gcc-fuzz/Debug/wasm2wat @@ ${ENABLE}
