@@ -35,6 +35,7 @@
 #include "src/make-unique.h"
 #include "src/result.h"
 #include "src/string-view.h"
+#include "src/type.h"
 
 #define WABT_FATAL(...) fprintf(stderr, __VA_ARGS__), exit(1)
 #define WABT_ARRAY_SIZE(a) (sizeof(a) / sizeof(a[0]))
@@ -101,15 +102,56 @@
 #define PRIoffset PRIzx
 
 struct v128 {
-  uint32_t v[4];
+  v128() = default;
+  v128(uint32_t x0, uint32_t x1, uint32_t x2, uint32_t x3) {
+    set_u32(0, x0);
+    set_u32(1, x1);
+    set_u32(2, x2);
+    set_u32(3, x3);
+  }
 
   bool operator==(const v128& other) const {
-    return v[0] == other.v[0] &&
-           v[1] == other.v[1] &&
-           v[2] == other.v[2] &&
-           v[3] == other.v[3];
+    return std::equal(std::begin(v), std::end(v), std::begin(other.v));
   }
   bool operator!=(const v128& other) const { return !(*this == other); }
+
+  uint8_t u8(int lane) const { return To<uint8_t>(lane); }
+  uint16_t u16(int lane) const { return To<uint16_t>(lane); }
+  uint32_t u32(int lane) const { return To<uint32_t>(lane); }
+  uint64_t u64(int lane) const { return To<uint64_t>(lane); }
+  uint32_t f32_bits(int lane) const { return To<uint32_t>(lane); }
+  uint64_t f64_bits(int lane) const { return To<uint64_t>(lane); }
+
+  void set_u8(int lane, uint8_t x) { return From<uint8_t>(lane, x); }
+  void set_u16(int lane, uint16_t x) { return From<uint16_t>(lane, x); }
+  void set_u32(int lane, uint32_t x) { return From<uint32_t>(lane, x); }
+  void set_u64(int lane, uint64_t x) { return From<uint64_t>(lane, x); }
+  void set_f32_bits(int lane, uint32_t x) { return From<uint32_t>(lane, x); }
+  void set_f64_bits(int lane, uint64_t x) { return From<uint64_t>(lane, x); }
+
+  bool is_zero() const {
+    return std::all_of(std::begin(v), std::end(v),
+                       [](uint8_t x) { return x == 0; });
+  }
+  void set_zero() { std::fill(std::begin(v), std::end(v), 0); }
+
+  template <typename T>
+  T To(int lane) const {
+    static_assert(sizeof(T) <= sizeof(v), "Invalid cast!");
+    assert((lane + 1) * sizeof(T) <= sizeof(v));
+    T result;
+    memcpy(&result, &v[lane * sizeof(T)], sizeof(result));
+    return result;
+  }
+
+  template <typename T>
+  void From(int lane, T data) {
+    static_assert(sizeof(T) <= sizeof(v), "Invalid cast!");
+    assert((lane + 1) * sizeof(T) <= sizeof(v));
+    memcpy(&v[lane * sizeof(T)], &data, sizeof(data));
+  }
+
+  uint8_t v[16];
 };
 
 namespace wabt {
@@ -123,7 +165,7 @@ static const Index kInvalidIndex = ~0;
 static const Offset kInvalidOffset = ~0;
 
 template <typename Dst, typename Src>
-Dst Bitcast(Src&& value) {
+Dst WABT_VECTORCALL Bitcast(Src&& value) {
   static_assert(sizeof(Src) == sizeof(Dst), "Bitcast sizes must match.");
   Dst result;
   memcpy(&result, &value, sizeof(result));
@@ -205,38 +247,16 @@ struct Location {
   };
 };
 
-// Matches binary format, do not change.
-enum class Type : int32_t {
-  I32 = -0x01,      // 0x7f
-  I64 = -0x02,      // 0x7e
-  F32 = -0x03,      // 0x7d
-  F64 = -0x04,      // 0x7c
-  V128 = -0x05,     // 0x7b
-  Funcref = -0x10,  // 0x70
-  Anyref = -0x11,   // 0x6f
-  Nullref = -0x12,  // 0x6e
-  Exnref = -0x18,   // 0x68
-  Func = -0x20,     // 0x60
-  Void = -0x40,     // 0x40
-  ___ = Void,       // Convenient for the opcode table in opcode.h
-  Any = 0,          // Not actually specified, but useful for type-checking
-  Hostref = 2,      // Not actually specified, but used in testing and type-checking
-  I8 = 3,           // Not actually specified, but used internally with load/store
-  I8U = 4,          // Not actually specified, but used internally with load/store
-  I16 = 5,          // Not actually specified, but used internally with load/store
-  I16U = 6,         // Not actually specified, but used internally with load/store
-  I32U = 7,         // Not actually specified, but used internally with load/store
-};
-typedef std::vector<Type> TypeVector;
-
 enum class SegmentKind {
   Active,
   Passive,
   Declared,
 };
 
-// Used in test asserts for special expected values "nan:canonical" and "nan:arithmetic"
+// Used in test asserts for special expected values "nan:canonical" and
+// "nan:arithmetic"
 enum class ExpectedNan {
+  None,
   Canonical,
   Arithmetic,
 };
@@ -392,80 +412,6 @@ static WABT_INLINE const char* GetSymbolTypeName(SymbolType type) {
   }
 }
 
-/* type */
-
-static WABT_INLINE bool IsRefType(Type t) {
-  return t == Type::Anyref || t == Type::Funcref || t == Type::Nullref ||
-         t == Type::Exnref || t == Type::Hostref;
-}
-
-static WABT_INLINE bool IsNullableRefType(Type t) {
-  /* Currently all reftypes are nullable */
-  return IsRefType(t);
-}
-
-static WABT_INLINE const char* GetTypeName(Type type) {
-  switch (type) {
-    case Type::I32:
-      return "i32";
-    case Type::I64:
-      return "i64";
-    case Type::F32:
-      return "f32";
-    case Type::F64:
-      return "f64";
-    case Type::V128:
-      return "v128";
-    case Type::Funcref:
-      return "funcref";
-    case Type::Func:
-      return "func";
-    case Type::Exnref:
-      return "exnref";
-    case Type::Void:
-      return "void";
-    case Type::Any:
-      return "any";
-    case Type::Anyref:
-      return "anyref";
-    case Type::Nullref:
-      return "nullref";
-    default:
-      return "<type_index>";
-  }
-}
-
-static WABT_INLINE bool IsTypeIndex(Type type) {
-  return static_cast<int32_t>(type) >= 0;
-}
-
-static WABT_INLINE Index GetTypeIndex(Type type) {
-  assert(IsTypeIndex(type));
-  return static_cast<Index>(type);
-}
-
-static WABT_INLINE TypeVector GetInlineTypeVector(Type type) {
-  assert(!IsTypeIndex(type));
-  switch (type) {
-    case Type::Void:
-      return TypeVector();
-
-    case Type::I32:
-    case Type::I64:
-    case Type::F32:
-    case Type::F64:
-    case Type::V128:
-    case Type::Funcref:
-    case Type::Anyref:
-    case Type::Nullref:
-    case Type::Exnref:
-      return TypeVector(&type, &type + 1);
-
-    default:
-      WABT_UNREACHABLE;
-  }
-}
-
 template <typename T>
 void ConvertBackslashToSlash(T begin, T end) {
   std::replace(begin, end, '\\', '/');
