@@ -24,13 +24,12 @@ namespace wabt {
 Opcode::Info Opcode::infos_[] = {
 #define WABT_OPCODE(rtype, type1, type2, type3, mem_size, prefix, code, Name, \
                     text, decomp)                                             \
-  {text, decomp, Type::rtype, Type::type1,                                    \
-   Type::type2, Type::type3, mem_size,                                        \
-   prefix,      code,        PrefixCode(prefix, code)},
+  {text,     decomp, Type::rtype, {Type::type1, Type::type2, Type::type3},    \
+   mem_size, prefix, code,        PrefixCode(prefix, code)},
 #include "src/opcode.def"
 #undef WABT_OPCODE
 
-  {"<invalid>", "", Type::Void, Type::Void, Type::Void, Type::Void, 0, 0, 0, 0},
+  {"<invalid>", "", Type::Void, {Type::Void, Type::Void, Type::Void}, 0, 0, 0, 0},
 };
 
 #define WABT_OPCODE(rtype, type1, type2, type3, mem_size, prefix, code, Name, \
@@ -95,6 +94,7 @@ bool Opcode::IsEnabled(const Features& features) const {
     case Opcode::AtomicNotify:
     case Opcode::I32AtomicWait:
     case Opcode::I64AtomicWait:
+    case Opcode::AtomicFence:
     case Opcode::I32AtomicLoad:
     case Opcode::I64AtomicLoad:
     case Opcode::I32AtomicLoad8U:
@@ -191,7 +191,6 @@ bool Opcode::IsEnabled(const Features& features) const {
     case Opcode::I16X8Sub:
     case Opcode::I32X4Sub:
     case Opcode::I64X2Sub:
-    case Opcode::I8X16Mul:
     case Opcode::I16X8Mul:
     case Opcode::I32X4Mul:
     case Opcode::I8X16Neg:
@@ -226,11 +225,9 @@ bool Opcode::IsEnabled(const Features& features) const {
     case Opcode::I8X16AnyTrue:
     case Opcode::I16X8AnyTrue:
     case Opcode::I32X4AnyTrue:
-    case Opcode::I64X2AnyTrue:
     case Opcode::I8X16AllTrue:
     case Opcode::I16X8AllTrue:
     case Opcode::I32X4AllTrue:
-    case Opcode::I64X2AllTrue:
     case Opcode::I8X16Eq:
     case Opcode::I16X8Eq:
     case Opcode::I32X4Eq:
@@ -293,18 +290,17 @@ bool Opcode::IsEnabled(const Features& features) const {
     case Opcode::F64X2Sqrt:
     case Opcode::F32X4ConvertI32X4S:
     case Opcode::F32X4ConvertI32X4U:
-    case Opcode::F64X2ConvertI64X2S:
-    case Opcode::F64X2ConvertI64X2U:
     case Opcode::I32X4TruncSatF32X4S:
     case Opcode::I32X4TruncSatF32X4U:
-    case Opcode::I64X2TruncSatF64X2S:
-    case Opcode::I64X2TruncSatF64X2U:
     case Opcode::V8X16Swizzle:
     case Opcode::V8X16Shuffle:
-    case Opcode::I8X16LoadSplat:
-    case Opcode::I16X8LoadSplat:
-    case Opcode::I32X4LoadSplat:
-    case Opcode::I64X2LoadSplat:
+    case Opcode::V8X16LoadSplat:
+    case Opcode::V16X8LoadSplat:
+    case Opcode::V32X4LoadSplat:
+    case Opcode::V64X2LoadSplat:
+    case Opcode::I8X16Abs:
+    case Opcode::I16X8Abs:
+    case Opcode::I32X4Abs:
       return features.simd_enabled();
 
     case Opcode::MemoryInit:
@@ -327,7 +323,7 @@ bool Opcode::IsEnabled(const Features& features) const {
     // Interpreter opcodes are never "enabled".
     case Opcode::InterpAlloca:
     case Opcode::InterpBrUnless:
-    case Opcode::InterpCallHost:
+    case Opcode::InterpCallImport:
     case Opcode::InterpData:
     case Opcode::InterpDropKeep:
       return false;
